# Table of Contents

- [configuring-sso-with-pingone](<./configuring-sso-with-pingone.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Configuring SSO with PingOne](<./Configuring-SSO-with-PingOne.md>)
  - [Prerequisites](<./Configuring-SSO-with-PingOne/Prerequisites.md>)
  - [Step 1: Create a SAML Application](<./Configuring-SSO-with-PingOne/Step-1-Create-a-SAML-Application.md>)
  - [Step 2: Configure SAML Settings](<./Configuring-SSO-with-PingOne/Step-2-Configure-SAML-Settings.md>)
  - [Step 3: Configure Attribute Mapping](<./Configuring-SSO-with-PingOne/Step-3-Configure-Attribute-Mapping.md>)
  - [Step 4: Assign Users to the SAML Application](<./Configuring-SSO-with-PingOne/Step-4-Assign-Users-to-the-SAML-Application.md>)
